==> rutorrent-3.9.tar.gz: ruTorrent-3.9/plugins/geoip/lang/fr.js <==
﻿/*
 * PLUGIN GEOIP
 *
 * French language file.
 *
 * Initial Author: art.spb, December 2009.
 *
 * Author: Nicobubulle (nicobubulle@gmail.com)
 */

 theUILang.peerComment		= "Ajouter un commentaire";
 theUILang.peerCommentLabel	= "Entrer un nouveau commentaire pour le peer";
 theUILang.commentName		= "Commentaire";
 theUILang.countryName		= "Pays";

 theUILang.country = new Array();
 theUILang.country[ "ad" ] = "Andorre";
 theUILang.country[ "ae" ] = "Émirats Arabes Unis";
 theUILang.country[ "af" ] = "Afghanistan";
 theUILang.country[ "ag" ] = "Antigua-et-Barbuda";
 theUILang.country[ "ai" ] = "Anguilla";
 theUILang.country[ "al" ] = "Albanie";
 theUILang.country[ "am" ] = "Arménie";
 theUILang.country[ "ao" ] = "Angola";
 theUILang.country[ "aq" ] = "Antarctique";
 theUILang.country[ "ar" ] = "Argentine";
 theUILang.country[ "as" ] = "Samoa Américaines";
 theUILang.country[ "at" ] = "Autriche";
 theUILang.country[ "au" ] = "Australie";
 theUILang.country[ "aw" ] = "Aruba";
 theUILang.country[ "ax" ] = "Îles Åland";
 theUILang.country[ "az" ] = "Azerbaïdjan";
 theUILang.country[ "ba" ] = "Bosnie-Herzégovine";
 theUILang.country[ "bb" ] = "La Barbade";
 theUILang.country[ "bd" ] = "Bangladesh";
 theUILang.country[ "be" ] = "Belgique";
 theUILang.country[ "bf" ] = "Burkina Faso";
 theUILang.country[ "bg" ] = "Bulgarie";
 theUILang.country[ "bh" ] = "Bahreïn";
 theUILang.country[ "bi" ] = "Burundi";
 theUILang.country[ "bj" ] = "Bénin";
 theUILang.country[ "bl" ] = "Saint-Barthélemy";
 theUILang.country[ "bm" ] = "Bermudes";
 theUILang.country[ "bn" ] = "Brunei";
 theUILang.country[ "bo" ] = "Bolivie";
 theUILang.country[ "bq" ] = "Bonaire";
 theUILang.country[ "br" ] = "Brésil";
 theUILang.country[ "bs" ] = "Bahamas";
 theUILang.country[ "bt" ] = "Bhoutan";
 theUILang.country[ "bv" ] = "Île Bouvet";
 theUILang.country[ "bw" ] = "Botswana";
 theUILang.country[ "by" ] = "Belarus";
 theUILang.country[ "bz" ] = "Belize";
 theUILang.country[ "ca" ] = "Canada";
 theUILang.country[ "cc" ] = "Îles Cocos";
 theUILang.country[ "cd" ] = "Congo-Kinshasa";
 theUILang.country[ "cf" ] = "République Centrafricaine";
 theUILang.country[ "cg" ] = "Congo-Brazzaville";
 theUILang.country[ "ch" ] = "Suisse";
 theUILang.country[ "ci" ] = "Côte d'Ivoire";
 theUILang.country[ "ck" ] = "Îles Cook";
 theUILang.country[ "cl" ] = "Chili";
 theUILang.country[ "cm" ] = "Cameroun";
 theUILang.country[ "cn" ] = "Chine";
 theUILang.country[ "co" ] = "Colombie";
 theUILang.country[ "cr" ] = "Costa Rica";
 theUILang.country[ "cu" ] = "Cuba";
 theUILang.country[ "cv" ] = "Cap-Vert";
 theUILang.country[ "cw" ] = "Curaçao";
 theUILang.country[ "cx" ] = "Île Christmas";
 theUILang.country[ "cy" ] = "Chypre";
 theUILang.country[ "cz" ] = "République Tchèque";
 theUILang.country[ "de" ] = "Allemagne";
 theUILang.country[ "dj" ] = "Djibouti";
 theUILang.country[ "dk" ] = "Danemark";
 theUILang.country[ "dm" ] = "Dominique";
 theUILang.country[ "do" ] = "République Dominicaine";
 theUILang.country[ "dz" ] = "Algérie";
 theUILang.country[ "ec" ] = "Equateur";
 theUILang.country[ "ee" ] = "Estonie";
 theUILang.country[ "eg" ] = "Egypte";
 theUILang.country[ "eh" ] = "Sahara Occidental";
 theUILang.country[ "er" ] = "Érythrée";
 theUILang.country[ "es" ] = "Espagne";
 theUILang.country[ "et" ] = "Ethiopie";
 theUILang.country[ "eu" ] = "Union Européenne";
 theUILang.country[ "fi" ] = "Finlande";
 theUILang.country[ "fj" ] = "Fidji";
 theUILang.country[ "fk" ] = "Îles Falkland";
 theUILang.country[ "fm" ] = "Micronésie";
 theUILang.country[ "fo" ] = "Îles Féroé";
 theUILang.country[ "fr" ] = "France";
 theUILang.country[ "ga" ] = "Gabon";
 theUILang.country[ "gb" ] = "Royaume-Uni";
 theUILang.country[ "gd" ] = "Grenade";
 theUILang.country[ "ge" ] = "Géorgie";
 theUILang.country[ "gf" ] = "Guyane Française";
 theUILang.country[ "gg" ] = "Guernesey";
 theUILang.country[ "gh" ] = "Ghana";
 theUILang.country[ "gi" ] = "Gibraltar";
 theUILang.country[ "gl" ] = "Groenland";
 theUILang.country[ "gm" ] = "Gambie";
 theUILang.country[ "gn" ] = "Guinée";
 theUILang.country[ "gp" ] = "Guadeloupe";
 theUILang.country[ "gq" ] = "Guinée Équatoriale";
 theUILang.country[ "gr" ] = "Grèce";
 theUILang.country[ "gs" ] = "Géorgie du Sud et Îles Sandwich du Sud";
 theUILang.country[ "gt" ] = "Guatemala";
 theUILang.country[ "gu" ] = "Guam";
 theUILang.country[ "gw" ] = "Guinée-Bissau";
 theUILang.country[ "gy" ] = "Guyane";
 theUILang.country[ "hk" ] = "Hong-Kong";
 theUILang.country[ "hm" ] = "Îles Heard et McDonald";
 theUILang.country[ "hn" ] = "Honduras";
 theUILang.country[ "hr" ] = "Croatie";
 theUILang.country[ "ht" ] = "Haïti";
 theUILang.country[ "hu" ] = "Hongrie";
 theUILang.country[ "id" ] = "Indonésie";
 theUILang.country[ "ie" ] = "Irlande";
 theUILang.country[ "il" ] = "Israël";
 theUILang.country[ "im" ] = "Île de Man";
 theUILang.country[ "in" ] = "Inde";
 theUILang.country[ "io" ] = "Territoire Britannique de l'Océan Indien";
 theUILang.country[ "iq" ] = "Irak";
 theUILang.country[ "ir" ] = "Iran";
 theUILang.country[ "is" ] = "Islande";
 theUILang.country[ "it" ] = "Italie";
 theUILang.country[ "je" ] = "Jersey";
 theUILang.country[ "jm" ] = "Jamaïque";
 theUILang.country[ "jo" ] = "Jordanie";
 theUILang.country[ "jp" ] = "Japon";
 theUILang.country[ "ke" ] = "Kenya";
 theUILang.country[ "kg" ] = "Kirghizistan";
 theUILang.country[ "kh" ] = "Cambodge";
 theUILang.country[ "ki" ] = "Kiribati";
 theUILang.country[ "km" ] = "Comores";
 theUILang.country[ "kn" ] = "Saint-Kitts-et-Nevis";
 theUILang.country[ "kp" ] = "Corée du Nord";
 theUILang.country[ "kr" ] = "Corée du Sud";
 theUILang.country[ "kw" ] = "Koweit";
 theUILang.country[ "ky" ] = "Îles Caïmans";
 theUILang.country[ "kz" ] = "Kazakhstan";
 theUILang.country[ "la" ] = "Laos";
 theUILang.country[ "lb" ] = "Liban";
 theUILang.country[ "lc" ] = "Sainte-Lucie";
 theUILang.country[ "li" ] = "Liechtenstein";
 theUILang.country[ "lk" ] = "Sri Lanka";
 theUILang.country[ "lr" ] = "Libéria";
 theUILang.country[ "ls" ] = "Lesotho";
 theUILang.country[ "lt" ] = "Lituanie";
 theUILang.country[ "lu" ] = "Luxembourg";
 theUILang.country[ "lv" ] = "Lettonie";
 theUILang.country[ "ly" ] = "Libye";
 theUILang.country[ "ma" ] = "Maroc";
 theUILang.country[ "mc" ] = "Monaco";
 theUILang.country[ "md" ] = "Moldavie";
 theUILang.country[ "me" ] = "Monténégro";
 theUILang.country[ "mf" ] = "Saint-Martin";
 theUILang.country[ "mg" ] = "Madagascar";
 theUILang.country[ "mh" ] = "Îles Marshall";
 theUILang.country[ "mk" ] = "Macédoine du Nord";
 theUILang.country[ "ml" ] = "Mali";
 theUILang.country[ "mm" ] = "Myanmar";
 theUILang.country[ "mn" ] = "Mongolie";
 theUILang.country[ "mo" ] = "Macao";
 theUILang.country[ "mp" ] = "Îles Mariannes du Nord";
 theUILang.country[ "mq" ] = "Martinique";
 theUILang.country[ "mr" ] = "Mauritanie";
 theUILang.country[ "ms" ] = "Montserrat";
 theUILang.country[ "mt" ] = "Malte";
 theUILang.country[ "mu" ] = "Île Maurice";
 theUILang.country[ "mv" ] = "Maldives";
 theUILang.country[ "mw" ] = "Malawi";
 theUILang.country[ "mx" ] = "Mexique";
 theUILang.country[ "my" ] = "Malaisie";
 theUILang.country[ "mz" ] = "Mozambique";
 theUILang.country[ "na" ] = "Namibie";
 theUILang.country[ "nc" ] = "Nouvelle-Calédonie";
 theUILang.country[ "ne" ] = "Niger";
 theUILang.country[ "nf" ] = "Île Norfolk";
 theUILang.country[ "ng" ] = "Nigeria";
 theUILang.country[ "ni" ] = "Nicaragua";
 theUILang.country[ "nl" ] = "Pays-Bas";
 theUILang.country[ "no" ] = "Norvège";
 theUILang.country[ "np" ] = "Népal";
 theUILang.country[ "nr" ] = "Nauru";
 theUILang.country[ "nu" ] = "Nioué";
 theUILang.country[ "nz" ] = "Nouvelle-Zélande";
 theUILang.country[ "om" ] = "Oman";
 theUILang.country[ "pa" ] = "Panama";
 theUILang.country[ "pe" ] = "Pérou";
 theUILang.country[ "pf" ] = "Polynésie Française";
 theUILang.country[ "pg" ] = "Papouasie-Nouvelle-Guinée";
 theUILang.country[ "ph" ] = "Philippines";
 theUILang.country[ "pk" ] = "Pakistan";
 theUILang.country[ "pl" ] = "Pologne";
 theUILang.country[ "pm" ] = "Saint-Pierre-et-Miquelon";
 theUILang.country[ "pn" ] = "Pitcairn";
 theUILang.country[ "pr" ] = "Porto Rico";
 theUILang.country[ "ps" ] = "Palestine";
 theUILang.country[ "pt" ] = "Portugal";
 theUILang.country[ "pw" ] = "Palau";
 theUILang.country[ "py" ] = "Paraguay";
 theUILang.country[ "qa" ] = "Qatar";
 theUILang.country[ "re" ] = "Réunion";
 theUILang.country[ "ro" ] = "Roumanie";
 theUILang.country[ "rs" ] = "Serbie";
 theUILang.country[ "ru" ] = "Russie";
 theUILang.country[ "rw" ] = "Rwanda";
 theUILang.country[ "sa" ] = "Arabie Saoudite";
 theUILang.country[ "sb" ] = "Îles Salomon";
 theUILang.country[ "sc" ] = "Seychelles";
 theUILang.country[ "sd" ] = "Soudan";
 theUILang.country[ "se" ] = "Suède";
 theUILang.country[ "sg" ] = "Singapour";
 theUILang.country[ "sh" ] = "Sainte-Hélène";
 theUILang.country[ "si" ] = "Slovénie";
 theUILang.country[ "sj" ] = "Svalbard et Jan Mayen";
 theUILang.country[ "sk" ] = "Slovaquie";
 theUILang.country[ "sl" ] = "Sierra Leone";
 theUILang.country[ "sm" ] = "Saint-Marin";
 theUILang.country[ "sn" ] = "Sénégal";
 theUILang.country[ "so" ] = "Somalie";
 theUILang.country[ "sr" ] = "Suriname";
 theUILang.country[ "ss" ] = "Soudan du Sud";
 theUILang.country[ "st" ] = "Sao Tomé et Principe";
 theUILang.country[ "sv" ] = "El Salvador";
 theUILang.country[ "sx" ] = "Saint-Martin";
 theUILang.country[ "sy" ] = "Syrie";
 theUILang.country[ "sz" ] = "Swaziland";
 theUILang.country[ "tc" ] = "Îles Turques et Caïques";
 theUILang.country[ "td" ] = "Tchad";
 theUILang.country[ "tf" ] = "Terres Australes Françaises";
 theUILang.country[ "tg" ] = "Togo";
 theUILang.country[ "th" ] = "Thaïlande";
 theUILang.country[ "tj" ] = "Tadjikistan";
 theUILang.country[ "tk" ] = "Tokélaou";
 theUILang.country[ "tl" ] = "Timor oriental";
 theUILang.country[ "tm" ] = "Turkménistan";
 theUILang.country[ "tn" ] = "Tunisie";
 theUILang.country[ "to" ] = "Tonga";
 theUILang.country[ "tr" ] = "Turquie";
 theUILang.country[ "tt" ] = "Trinité-et-Tobago";
 theUILang.country[ "tv" ] = "Tuvalu";
 theUILang.country[ "tw" ] = "Taiwan";
 theUILang.country[ "tz" ] = "Tanzanie";
 theUILang.country[ "ua" ] = "Ukraine";
 theUILang.country[ "ug" ] = "Ouganda";
 theUILang.country[ "um" ] = "Îles mineures éloignées des États-Unis";
 theUILang.country[ "un" ] = "Inconnu";
 theUILang.country[ "us" ] = "États-Unis";
 theUILang.country[ "uy" ] = "Uruguay";
 theUILang.country[ "uz" ] = "Ouzbékistan";
 theUILang.country[ "va" ] = "Vatican";
 theUILang.country[ "vc" ] = "Saint-Vincent-et-les Grenadines";
 theUILang.country[ "ve" ] = "Venezuela";
 theUILang.country[ "vg" ] = "Îles Vierges Britanniques";
 theUILang.country[ "vi" ] = "Îles Vierges Américaines";
 theUILang.country[ "vn" ] = "Viet Nam";
 theUILang.country[ "vu" ] = "Vanuatu";
 theUILang.country[ "wf" ] = "Wallis et Futuna";
 theUILang.country[ "ws" ] = "Samoa";
 theUILang.country[ "ye" ] = "Yémen";
 theUILang.country[ "yt" ] = "Mayotte";
 theUILang.country[ "za" ] = "Afrique du Sud";
 theUILang.country[ "zm" ] = "Zambie";
 theUILang.country[ "zw" ] = "Zimbabwe";

thePlugins.get("geoip").langLoaded();

==> rutorrent-4.3.6.tar.gz: ruTorrent-4.3.6/plugins/geoip/lang/fr.js <==
﻿/*
 * PLUGIN GEOIP
 *
 * French language file.
 *
 * Initial Author: art.spb, December 2009.
 *
 * Author: Nicobubulle (nicobubulle@gmail.com)
 */

 theUILang.peerComment		= "Ajouter un commentaire";
 theUILang.peerCommentLabel	= "Entrer un nouveau commentaire pour ce client";
 theUILang.commentName		= "Commentaire";
 theUILang.countryName		= "Pays";

 theUILang.country = new Array();
 theUILang.country[ "ad" ] = "Andorre";
 theUILang.country[ "ae" ] = "Émirats Arabes Unis";
 theUILang.country[ "af" ] = "Afghanistan";
 theUILang.country[ "ag" ] = "Antigua-et-Barbuda";
 theUILang.country[ "ai" ] = "Anguilla";
 theUILang.country[ "al" ] = "Albanie";
 theUILang.country[ "am" ] = "Arménie";
 theUILang.country[ "ao" ] = "Angola";
 theUILang.country[ "aq" ] = "Antarctique";
 theUILang.country[ "ar" ] = "Argentine";
 theUILang.country[ "as" ] = "Samoa Américaines";
 theUILang.country[ "at" ] = "Autriche";
 theUILang.country[ "au" ] = "Australie";
 theUILang.country[ "aw" ] = "Aruba";
 theUILang.country[ "ax" ] = "Îles Åland";
 theUILang.country[ "az" ] = "Azerbaïdjan";
 theUILang.country[ "ba" ] = "Bosnie-Herzégovine";
 theUILang.country[ "bb" ] = "La Barbade";
 theUILang.country[ "bd" ] = "Bangladesh";
 theUILang.country[ "be" ] = "Belgique";
 theUILang.country[ "bf" ] = "Burkina Faso";
 theUILang.country[ "bg" ] = "Bulgarie";
 theUILang.country[ "bh" ] = "Bahreïn";
 theUILang.country[ "bi" ] = "Burundi";
 theUILang.country[ "bj" ] = "Bénin";
 theUILang.country[ "bl" ] = "Saint-Barthélemy";
 theUILang.country[ "bm" ] = "Bermudes";
 theUILang.country[ "bn" ] = "Brunei";
 theUILang.country[ "bo" ] = "Bolivie";
 theUILang.country[ "bq" ] = "Bonaire";
 theUILang.country[ "br" ] = "Brésil";
 theUILang.country[ "bs" ] = "Bahamas";
 theUILang.country[ "bt" ] = "Bhoutan";
 theUILang.country[ "bv" ] = "Île Bouvet";
 theUILang.country[ "bw" ] = "Botswana";
 theUILang.country[ "by" ] = "Belarus";
 theUILang.country[ "bz" ] = "Belize";
 theUILang.country[ "ca" ] = "Canada";
 theUILang.country[ "cc" ] = "Îles Cocos";
 theUILang.country[ "cd" ] = "Congo-Kinshasa";
 theUILang.country[ "cf" ] = "République Centrafricaine";
 theUILang.country[ "cg" ] = "Congo-Brazzaville";
 theUILang.country[ "ch" ] = "Suisse";
 theUILang.country[ "ci" ] = "Côte d'Ivoire";
 theUILang.country[ "ck" ] = "Îles Cook";
 theUILang.country[ "cl" ] = "Chili";
 theUILang.country[ "cm" ] = "Cameroun";
 theUILang.country[ "cn" ] = "Chine";
 theUILang.country[ "co" ] = "Colombie";
 theUILang.country[ "cr" ] = "Costa Rica";
 theUILang.country[ "cu" ] = "Cuba";
 theUILang.country[ "cv" ] = "Cap-Vert";
 theUILang.country[ "cw" ] = "Curaçao";
 theUILang.country[ "cx" ] = "Île Christmas";
 theUILang.country[ "cy" ] = "Chypre";
 theUILang.country[ "cz" ] = "République Tchèque";
 theUILang.country[ "de" ] = "Allemagne";
 theUILang.country[ "dj" ] = "Djibouti";
 theUILang.country[ "dk" ] = "Danemark";
 theUILang.country[ "dm" ] = "Dominique";
 theUILang.country[ "do" ] = "République Dominicaine";
 theUILang.country[ "dz" ] = "Algérie";
 theUILang.country[ "ec" ] = "Équateur";
 theUILang.country[ "ee" ] = "Estonie";
 theUILang.country[ "eg" ] = "Égypte";
 theUILang.country[ "eh" ] = "Sahara Occidental";
 theUILang.country[ "er" ] = "Érythrée";
 theUILang.country[ "es" ] = "Espagne";
 theUILang.country[ "et" ] = "Éthiopie";
 theUILang.country[ "eu" ] = "Union Européenne";
 theUILang.country[ "fi" ] = "Finlande";
 theUILang.country[ "fj" ] = "Fidji";
 theUILang.country[ "fk" ] = "Îles Falkland";
 theUILang.country[ "fm" ] = "Micronésie";
 theUILang.country[ "fo" ] = "Îles Féroé";
 theUILang.country[ "fr" ] = "France";
 theUILang.country[ "ga" ] = "Gabon";
 theUILang.country[ "gb" ] = "Royaume-Uni";
 theUILang.country[ "gd" ] = "Grenade";
 theUILang.country[ "ge" ] = "Géorgie";
 theUILang.country[ "gf" ] = "Guyane Française";
 theUILang.country[ "gg" ] = "Guernesey";
 theUILang.country[ "gh" ] = "Ghana";
 theUILang.country[ "gi" ] = "Gibraltar";
 theUILang.country[ "gl" ] = "Groenland";
 theUILang.country[ "gm" ] = "Gambie";
 theUILang.country[ "gn" ] = "Guinée";
 theUILang.country[ "gp" ] = "Guadeloupe";
 theUILang.country[ "gq" ] = "Guinée Équatoriale";
 theUILang.country[ "gr" ] = "Grèce";
 theUILang.country[ "gs" ] = "Géorgie du Sud et Îles Sandwich du Sud";
 theUILang.country[ "gt" ] = "Guatemala";
 theUILang.country[ "gu" ] = "Guam";
 theUILang.country[ "gw" ] = "Guinée-Bissau";
 theUILang.country[ "gy" ] = "Guyane";
 theUILang.country[ "hk" ] = "Hong-Kong";
 theUILang.country[ "hm" ] = "Îles Heard et McDonald";
 theUILang.country[ "hn" ] = "Honduras";
 theUILang.country[ "hr" ] = "Croatie";
 theUILang.country[ "ht" ] = "Haïti";
 theUILang.country[ "hu" ] = "Hongrie";
 theUILang.country[ "id" ] = "Indonésie";
 theUILang.country[ "ie" ] = "Irlande";
 theUILang.country[ "il" ] = "Israël";
 theUILang.country[ "im" ] = "Île de Man";
 theUILang.country[ "in" ] = "Inde";
 theUILang.country[ "io" ] = "Territoire Britannique de l'Océan Indien";
 theUILang.country[ "iq" ] = "Irak";
 theUILang.country[ "ir" ] = "Iran";
 theUILang.country[ "is" ] = "Islande";
 theUILang.country[ "it" ] = "Italie";
 theUILang.country[ "je" ] = "Jersey";
 theUILang.country[ "jm" ] = "Jamaïque";
 theUILang.country[ "jo" ] = "Jordanie";
 theUILang.country[ "jp" ] = "Japon";
 theUILang.country[ "ke" ] = "Kenya";
 theUILang.country[ "kg" ] = "Kirghizistan";
 theUILang.country[ "kh" ] = "Cambodge";
 theUILang.country[ "ki" ] = "Kiribati";
 theUILang.country[ "km" ] = "Comores";
 theUILang.country[ "kn" ] = "Saint-Kitts-et-Nevis";
 theUILang.country[ "kp" ] = "Corée du Nord";
 theUILang.country[ "kr" ] = "Corée du Sud";
 theUILang.country[ "kw" ] = "Koweit";
 theUILang.country[ "ky" ] = "Îles Caïmans";
 theUILang.country[ "kz" ] = "Kazakhstan";
 theUILang.country[ "la" ] = "Laos";
 theUILang.country[ "lb" ] = "Liban";
 theUILang.country[ "lc" ] = "Sainte-Lucie";
 theUILang.country[ "li" ] = "Liechtenstein";
 theUILang.country[ "lk" ] = "Sri Lanka";
 theUILang.country[ "lr" ] = "Libéria";
 theUILang.country[ "ls" ] = "Lesotho";
 theUILang.country[ "lt" ] = "Lituanie";
 theUILang.country[ "lu" ] = "Luxembourg";
 theUILang.country[ "lv" ] = "Lettonie";
 theUILang.country[ "ly" ] = "Libye";
 theUILang.country[ "ma" ] = "Maroc";
 theUILang.country[ "mc" ] = "Monaco";
 theUILang.country[ "md" ] = "Moldavie";
 theUILang.country[ "me" ] = "Monténégro";
 theUILang.country[ "mf" ] = "Saint-Martin";
 theUILang.country[ "mg" ] = "Madagascar";
 theUILang.country[ "mh" ] = "Îles Marshall";
 theUILang.country[ "mk" ] = "Macédoine du Nord";
 theUILang.country[ "ml" ] = "Mali";
 theUILang.country[ "mm" ] = "Myanmar";
 theUILang.country[ "mn" ] = "Mongolie";
 theUILang.country[ "mo" ] = "Macao";
 theUILang.country[ "mp" ] = "Îles Mariannes du Nord";
 theUILang.country[ "mq" ] = "Martinique";
 theUILang.country[ "mr" ] = "Mauritanie";
 theUILang.country[ "ms" ] = "Montserrat";
 theUILang.country[ "mt" ] = "Malte";
 theUILang.country[ "mu" ] = "Île Maurice";
 theUILang.country[ "mv" ] = "Maldives";
 theUILang.country[ "mw" ] = "Malawi";
 theUILang.country[ "mx" ] = "Mexique";
 theUILang.country[ "my" ] = "Malaisie";
 theUILang.country[ "mz" ] = "Mozambique";
 theUILang.country[ "na" ] = "Namibie";
 theUILang.country[ "nc" ] = "Nouvelle-Calédonie";
 theUILang.country[ "ne" ] = "Niger";
 theUILang.country[ "nf" ] = "Île Norfolk";
 theUILang.country[ "ng" ] = "Nigeria";
 theUILang.country[ "ni" ] = "Nicaragua";
 theUILang.country[ "nl" ] = "Pays-Bas";
 theUILang.country[ "no" ] = "Norvège";
 theUILang.country[ "np" ] = "Népal";
 theUILang.country[ "nr" ] = "Nauru";
 theUILang.country[ "nu" ] = "Nioué";
 theUILang.country[ "nz" ] = "Nouvelle-Zélande";
 theUILang.country[ "om" ] = "Oman";
 theUILang.country[ "pa" ] = "Panama";
 theUILang.country[ "pe" ] = "Pérou";
 theUILang.country[ "pf" ] = "Polynésie Française";
 theUILang.country[ "pg" ] = "Papouasie-Nouvelle-Guinée";
 theUILang.country[ "ph" ] = "Philippines";
 theUILang.country[ "pk" ] = "Pakistan";
 theUILang.country[ "pl" ] = "Pologne";
 theUILang.country[ "pm" ] = "Saint-Pierre-et-Miquelon";
 theUILang.country[ "pn" ] = "Pitcairn";
 theUILang.country[ "pr" ] = "Porto Rico";
 theUILang.country[ "ps" ] = "Palestine";
 theUILang.country[ "pt" ] = "Portugal";
 theUILang.country[ "pw" ] = "Palau";
 theUILang.country[ "py" ] = "Paraguay";
 theUILang.country[ "qa" ] = "Qatar";
 theUILang.country[ "re" ] = "Réunion";
 theUILang.country[ "ro" ] = "Roumanie";
 theUILang.country[ "rs" ] = "Serbie";
 theUILang.country[ "ru" ] = "Russie";
 theUILang.country[ "rw" ] = "Rwanda";
 theUILang.country[ "sa" ] = "Arabie Saoudite";
 theUILang.country[ "sb" ] = "Îles Salomon";
 theUILang.country[ "sc" ] = "Seychelles";
 theUILang.country[ "sd" ] = "Soudan";
 theUILang.country[ "se" ] = "Suède";
 theUILang.country[ "sg" ] = "Singapour";
 theUILang.country[ "sh" ] = "Sainte-Hélène";
 theUILang.country[ "si" ] = "Slovénie";
 theUILang.country[ "sj" ] = "Svalbard et Jan Mayen";
 theUILang.country[ "sk" ] = "Slovaquie";
 theUILang.country[ "sl" ] = "Sierra Leone";
 theUILang.country[ "sm" ] = "Saint-Marin";
 theUILang.country[ "sn" ] = "Sénégal";
 theUILang.country[ "so" ] = "Somalie";
 theUILang.country[ "sr" ] = "Suriname";
 theUILang.country[ "ss" ] = "Soudan du Sud";
 theUILang.country[ "st" ] = "Sao Tomé et Principe";
 theUILang.country[ "sv" ] = "El Salvador";
 theUILang.country[ "sx" ] = "Saint-Martin";
 theUILang.country[ "sy" ] = "Syrie";
 theUILang.country[ "sz" ] = "Swaziland";
 theUILang.country[ "tc" ] = "Îles Turques et Caïques";
 theUILang.country[ "td" ] = "Tchad";
 theUILang.country[ "tf" ] = "Terres Australes Françaises";
 theUILang.country[ "tg" ] = "Togo";
 theUILang.country[ "th" ] = "Thaïlande";
 theUILang.country[ "tj" ] = "Tadjikistan";
 theUILang.country[ "tk" ] = "Tokélaou";
 theUILang.country[ "tl" ] = "Timor oriental";
 theUILang.country[ "tm" ] = "Turkménistan";
 theUILang.country[ "tn" ] = "Tunisie";
 theUILang.country[ "to" ] = "Tonga";
 theUILang.country[ "tr" ] = "Turquie";
 theUILang.country[ "tt" ] = "Trinité-et-Tobago";
 theUILang.country[ "tv" ] = "Tuvalu";
 theUILang.country[ "tw" ] = "Taiwan";
 theUILang.country[ "tz" ] = "Tanzanie";
 theUILang.country[ "ua" ] = "Ukraine";
 theUILang.country[ "ug" ] = "Ouganda";
 theUILang.country[ "um" ] = "Îles mineures éloignées des États-Unis";
 theUILang.country[ "un" ] = "Inconnu";
 theUILang.country[ "us" ] = "États-Unis";
 theUILang.country[ "uy" ] = "Uruguay";
 theUILang.country[ "uz" ] = "Ouzbékistan";
 theUILang.country[ "va" ] = "Vatican";
 theUILang.country[ "vc" ] = "Saint-Vincent-et-les Grenadines";
 theUILang.country[ "ve" ] = "Venezuela";
 theUILang.country[ "vg" ] = "Îles Vierges Britanniques";
 theUILang.country[ "vi" ] = "Îles Vierges Américaines";
 theUILang.country[ "vn" ] = "Viet Nam";
 theUILang.country[ "vu" ] = "Vanuatu";
 theUILang.country[ "wf" ] = "Wallis et Futuna";
 theUILang.country[ "ws" ] = "Samoa";
 theUILang.country[ "ye" ] = "Yémen";
 theUILang.country[ "yt" ] = "Mayotte";
 theUILang.country[ "za" ] = "Afrique du Sud";
 theUILang.country[ "zm" ] = "Zambie";
 theUILang.country[ "zw" ] = "Zimbabwe";

thePlugins.get("geoip").langLoaded();
